%%This file produces IRFs based on a Bayesian estimation for the Consumption Euler Equation with External Habit Formation
%priors are taken from Smets&Wouters (2007)


var y infl r epsD epsA epsM;
var y_obs infl_obs r_obs; 


varexo epsDS epsAS epsMS;

parameters sigma betta eta gama theta phipi rhoD rhoA rhoM;


sigma = 1;
betta = 0.99;
eta = 2.0;
gama = 0.7; %habit formation parameter 
theta = 0.5;
phipi = 1.5;
rhoD = 0.75; 
rhoA = 0.95;
rhoM = 0.5;



model(linear);


[name='IScurve']
y=(1/(1+gama))*y(+1)+(gama/(1+gama))*y(-1)-(1-gama)/(sigma*(1+gama))*(r-infl(+1))+(1-gama)/(sigma*(1+gama))*epsD;


[name='Phillips Curve']
infl = betta*infl(+1)+((1-betta*theta)*(1-theta)/theta)*(((eta*(1-gama)+sigma)/(1-gama))*y-(1+eta)*epsA-(gama*sigma/(1-gama))*y(-1));


[name='Monetary policy rule']
r = phipi*infl+epsM; 


[name='Demand shock']
epsD = rhoD*epsD(-1)+epsDS;

[name='Technology shock']
epsA = rhoA*epsA(-1)+epsAS;

[name='Monetary policy shock']
epsM = rhoM*epsM(-1)+epsMS;

[name='measurement equations']
y_obs=y-y(-1);
infl_obs =infl;
r_obs=r;




end;
steady;
check;



estimated_params;

%parameter_name      initial_value    LB        UB       prior_shape            prior_mean      prior_stderr


%parameters utility function
sigma,                  ,               ,       ,           normal_pdf,         1.5,            0.375;
betta,                  ,               ,       ,           gamma_pdf,          0.9975,         0.1;
gama,                   ,               ,       ,           beta_pdf,           0.7,            0.1;
eta,                    ,               ,       ,           normal_pdf,         2,              0.75;
theta,                  ,               ,       ,           beta_pdf,           0.5,            0.1;

%parameters monetary policy rule
phipi,                  ,               ,       ,           normal_pdf,         1.5,            0.125;

%exogenous processes-stderr
stderr epsDS,           ,               ,       ,           inv_gamma_pdf,      0.1,            2;                                          
stderr epsAS,           ,               ,       ,           inv_gamma_pdf,      0.1,            2;           
stderr epsMS,           ,               ,       ,           inv_gamma_pdf,      0.1,            2;             

%exogenous processes-autocorrelation 
rhoD,                   ,               ,       ,           beta_pdf,           0.5,            0.2;
rhoA,                   ,               ,       ,           beta_pdf,           0.5,            0.2;
rhoM,                   ,               ,       ,           beta_pdf,           0.5,            0.2;


end;

varobs y_obs infl_obs r_obs;


estimation (datafile='datafile100.xlsx',xls_sheet=sheet1, xls_range=A1:C202, first_obs=1, mode_compute=5, mh_jscale=0.57,mh_replic=250000, mh_drop=0.2,mh_nblocks=2,mh_conf_sig = 0.95, bayesian_irf,irf=30)y_obs infl_obs r_obs;


